@@ -13,6 +13,7 @@ def get_config_file():
         config_file = 'baskit.conf'
     return config_file
 
+
 sample_config = '''
 [Server]
 name            = default
@@ -24,17 +25,8 @@ server_branch   = stable
 server_build    = 1.0
 min_mem         = 1024
 max_mem         = 1024
+screen_log      = no
+terminal_out    = yes
+ramdisk         = no
 worlds          = world, world_nether, world_the_end
-
-[World: world]
-ramdisk         = no
-automount       = no
-
-[World: world_nether]
-ramdisk         = no
-automount       = no
-
-[World: world_the_end]
-ramdisk         = no
-automount       = no
 '''
\ No newline at end of file
